{ stdenv
, pkg-config
, buildPackages
, callPackage
, cairo
, clutter
, fetchFromGitHub
, fetchurl
, gobject-introspection
, gtk3
, lib
, lua53Packages
, lua5_3
, makeDesktopItem
, makeWrapper
, wrapGAppsHook3
, writeText
, osm-gps-map
, glib-networking
, copyDesktopItems
}:
let
  luaPackages = lua53Packages;
  fennel = luaPackages.fennel;
  lgi = luaPackages.buildLuaPackage {
    pname = "lgi";
    version = "0.9.2-2";
    buildInputs = [ gobject-introspection ];
    nativeBuildInputs = [ pkg-config ];

    src = fetchFromGitHub {
      owner = "lgi-devs";
      repo = "lgi";
      rev = "a412921fad445bcfc05a21148722a92ecb93ad06";
      hash = "sha256-kZBpH5gcaCNU134Wn6JXAkFELzmiphc1PeCtmN9cagc=";
    };
  };
  rxi-json = callPackage ../rxi-json { lua = lua5_3; };
  lua = lua5_3.withPackages (ps: with ps; [
    lgi
    luafilesystem
    luaposix
    readline
    http
    rxi-json
  ]);
  pname = "maps";
in stdenv.mkDerivation {
  inherit pname;
  version = "0.1";
  src =./.;

  buildInputs = [
    lua
    gtk3.dev
    cairo.dev
    gobject-introspection
    glib-networking
  ];
  nativeBuildInputs = [
#    lua
    gobject-introspection
    makeWrapper
    fennel
    wrapGAppsHook3
    copyDesktopItems
  ];
  GIO_EXTRA_MODULES = [ "${glib-networking.out}/lib/gio/modules" ];
  RXI_JSON="${rxi-json}/";

  makeFlags = [ "PREFIX=${placeholder "out"}" "NAME=${pname}" ];

  postInstall = ''
    mkdir -p $out/share/icons/
    cp icon.svg  $out/share/icons/${pname}.svg
  '';

  desktopItems = [
    (makeDesktopItem {
      name = pname;
      desktopName = "Maps";
      exec = pname;
      type = "Application";
      icon = "nix-snowflake"; # "${placeholder "out"}/share/icons/${pname}.svg";
    })
  ];
}
